Commit eda24d2f authored by Andreas Tille's avatar Andreas Tille
Browse files

Commit missing file

parent 6c7ee0a1
Loading
Loading
Loading
Loading
+52 −0
Original line number Diff line number Diff line
Author: Andreas Tille <tille@debian.org>
Last-Update: Tue, 21 Nov 2017 15:29:17 +0100
Desription: Fix spelling

diff --git a/MAGE/XML/Handler.pm b/MAGE/XML/Handler.pm
index 97b2c6c..e5cfcfe 100644
--- a/MAGE/XML/Handler.pm
+++ b/MAGE/XML/Handler.pm
@@ -82,7 +82,7 @@ sub unhandled {
 
 
 ###############################################################################
-# count: setter/getter for the scalar to track counting ouput
+# count: setter/getter for the scalar to track counting output
 ###############################################################################
 sub count {
   my $self = shift;
diff --git a/MAGE/XML/Writer.pm b/MAGE/XML/Writer.pm
index e643bfd..ae31722 100644
--- a/MAGE/XML/Writer.pm
+++ b/MAGE/XML/Writer.pm
@@ -920,7 +920,7 @@ sub data_format {
 
 The C<fh> attribute only controls where the main MAGE-ML document is
 written. If the C<external_data> attribute is set, the writer will
-also create a seperate external data file for each data cube.
+also create a separate external data file for each data cube.
 
 The C<external_data_dir> controls what director those files are
 written to.
diff --git a/MAGE/XML/Reader.pm b/MAGE/XML/Reader.pm
index 8e075fd..15986ec 100644
--- a/MAGE/XML/Reader.pm
+++ b/MAGE/XML/Reader.pm
@@ -124,7 +124,7 @@ sub sax1 {
 }
 
 ###############################################################################
 # count: setter/getter for the scalar to track counting ouput
 ###############################################################################
 sub count {
   my $self = shift;
@@ -151,7 +151,7 @@ output
 
 =item * log_file
 
-called with the file handle to which ouput should be sent
+called with the file handle to which output should be sent
 
 =item * init
 
@@ -124,7 +124,7 @@ sub sax1 {
 
 ###############################################################################
-# count: setter/getter for the scalar to track counting ouput
+# count: setter/getter for the scalar to track counting output
 ###############################################################################
 sub count {